@@ -26,16 +26,27 @@ def string_to_shape(node_string, bias=False):
     return m if m is None else tuple(int(x) for x in m.groups()[0].split(','))
 
 
-def parse_node_info(node):
+def _parse_node_inputs(node):
     inputs = {}
     inputs_names = []
     for idx, inp in enumerate(node.inputs()):
         inp = str(inp)
         curr_node_name = re.search(r'(.*) defined in ', inp).group(1)
-        extracted_data = re.search(r'%' + curr_node_name + r' : Float\(([^%]*)\)[,| ]', inp).group(1)
+        extracted_data = re.search(r'%' + curr_node_name + r' : Float\(([^%]*)\)[,| ]', inp)
+        if extracted_data is not None:
+            extracted_data = extracted_data.group(1)
+        else:
+            return _parse_node_inputs(
+                list(node.inputs())[0].node()
+            )
         inputs[curr_node_name] = re.findall(r'([0-9]*):', extracted_data)
         inputs[curr_node_name] = list(map(int, inputs[curr_node_name]))
         inputs_names.append(curr_node_name)
+    return inputs, inputs_names
+
+
+def parse_node_info(node):
+    inputs, inputs_names = _parse_node_inputs(node)
     node = str(node)
     node_name = re.search(r'%(.*) : ', node).group(1)
     out_size = re.search(r'Float\([0-9]+:([0-9]+),', node).group(1)
@@ -110,7 +121,7 @@ def _count_avgpool(node, version=2):
         out = string_to_shape(list(node.outputs())[0])
         out_ops = reduce(lambda x, y: x * y, out)
     elif version == 2:
-        node_name, io_node_names, out_ops = parse_node_info(node)
+        node_name, inputs, inputs_names, out_ops = parse_node_info(node)
 
     ops_add = reduce(lambda x, y: x * y, node['kernel_shape']) - 1
     ops_div = 1
